==> adminer-3.6.3.tbz: www/adminer/adminer/lang/fr.inc.php <==
<?php
$translations = array(
	'Login' => 'Authentification',
	'Logout successful.' => 'Au revoir !',
	'Invalid credentials.' => 'Authentification échouée.',
	'Server' => 'Serveur',
	'Username' => 'Utilisateur',
	'Password' => 'Mot de passe',
	'Select database' => 'Sélectionner la base de données',
	'Invalid database.' => 'Base de données invalide.',
	'Create new database' => 'Créer une base de données',
	'Table has been dropped.' => 'La table a été effacée.',
	'Table has been altered.' => 'La table a été modifiée.',
	'Table has been created.' => 'La table a été créée.',
	'Alter table' => 'Modifier la table',
	'Create table' => 'Créer une table',
	'Table name' => 'Nom de la table',
	'engine' => 'moteur',
	'collation' => 'interclassement',
	'Column name' => 'Nom de la colonne',
	'Type' => 'Type',
	'Length' => 'Longueur',
	'Auto Increment' => 'Auto increment',
	'Options' => 'Options',
	'Save' => 'Sauvegarder',
	'Drop' => 'Supprimer',
	'Database has been created.' => 'La base de données a été créée.',
	'Database has been renamed.' => 'La base de données a été renommée.',
	'Database has been altered.' => 'La base de données a été modifiée.',
	'Alter database' => 'Modifier la base de données',
	'Create database' => 'Créer une base de données',
	'SQL command' => 'Requête SQL',
	'Dump' => 'Exporter',
	'Logout' => 'Déconnexion',
	'database' => 'base de données',
	'Use' => 'Utiliser',
	'No tables.' => 'Aucune table.',
	'select' => 'select',
	'Create new table' => 'Créer une nouvelle table',
	'Item has been deleted.' => 'L\'élément a été supprimé.',
	'Item has been updated.' => 'L\'élément a été modifié.',
	'Edit' => 'Modifier',
	'Insert' => 'Insérer',
	'Save and insert next' => 'Sauvegarder et insérer le prochain',
	'Delete' => 'Effacer',
	'Database' => 'Base de données',
	'Routines' => 'Routines',
	'Indexes have been altered.' => 'Index modifiés.',
	'Indexes' => 'Index',
	'Alter indexes' => 'Modifier les index',
	'Add next' => 'Ajouter le prochain',
	'Language' => 'Langue',
	'Select' => 'Select',
	'New item' => 'Nouvel élément',
	'Search' => 'Rechercher',
	'Sort' => 'Trier',
	'descending' => 'décroissant',
	'Limit' => 'Limite',
	'No rows.' => 'Aucun résultat.',
	'Action' => 'Action',
	'edit' => 'modifier',
	'Page' => 'Page',
	'Query executed OK, %d row(s) affected.' => array('Requête exécutée avec succès, %d ligne modifiée.', 'Requête exécutée avec succès, %d lignes modifiées.'),
	'Error in query' => 'Erreur dans la requête',
	'Execute' => 'Exécuter',
	'Table' => 'Table',
	'Foreign keys' => 'Clés étrangères',
	'Triggers' => 'Triggers',
	'View' => 'Vue',
	'Unable to select the table' => 'Impossible de sélectionner la table',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF invalide. Veuillez réenvoyer le formulaire.',
	'Comment' => 'Commentaire',
	'Default values' => 'Valeurs par défaut',
	'%d byte(s)' => array('%d octet', '%d octets'),
	'No commands to execute.' => 'Aucune commande à exécuter.',
	'Unable to upload a file.' => 'Impossible d\'importer le fichier.',
	'File upload' => 'Importer un fichier',
	'File uploads are disabled.' => 'L\'importation de fichier est désactivée.',
	'Routine has been called, %d row(s) affected.' => array('La routine a été exécutée, %d ligne modifiée.', 'La routine a été exécutée, %d lignes modifiées.'),
	'Call' => 'Appeler',
	'No extension' => 'Extension introuvable',
	'None of the supported PHP extensions (%s) are available.' => 'Aucune des extensions PHP supportées (%s) n\'est disponible.',
	'Session support must be enabled.' => 'Veuillez activer les sessions.',
	'Session expired, please login again.' => 'Session expirée, veuillez vous authentifier à nouveau.',
	'Text length' => 'Longueur du texte',
	'Foreign key has been dropped.' => 'La clé étrangère a été effacée.',
	'Foreign key has been altered.' => 'La clé étrangère a été modifiée.',
	'Foreign key has been created.' => 'La clé étrangère a été créée.',
	'Foreign key' => 'Clé étrangère',
	'Target table' => 'Table visée',
	'Change' => 'Modifier',
	'Source' => 'Source',
	'Target' => 'Cible',
	'Add column' => 'Ajouter une colonne',
	'Alter' => 'Modifier',
	'Add foreign key' => 'Ajouter une clé étrangère',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Type d\'index',
	'Column (length)' => 'Colonne (longueur)',
	'View has been dropped.' => 'La vue a été effacée.',
	'View has been altered.' => 'La vue a été modifiée.',
	'View has been created.' => 'La vue a été créée.',
	'Alter view' => 'Modifier une vue',
	'Create view' => 'Créer une vue',
	'Name' => 'Nom',
	'Process list' => 'Liste des processus',
	'%d process(es) have been killed.' => array('%d processus a été arrêté.', '%d processus ont été arrêtés.'),
	'Kill' => 'Arrêter',
	'Parameter name' => 'Nom du paramètre',
	'Database schema' => 'Schéma de la base de données',
	'Create procedure' => 'Créer une procédure',
	'Create function' => 'Créer une fonction',
	'Routine has been dropped.' => 'La routine a été supprimée.',
	'Routine has been altered.' => 'La routine a été modifiée.',
	'Routine has been created.' => 'La routine a été créée.',
	'Alter function' => 'Modifier la fonction',
	'Alter procedure' => 'Modifier la procédure',
	'Return type' => 'Type de retour',
	'Add trigger' => 'Ajouter un trigger',
	'Trigger has been dropped.' => 'Le trigger a été supprimé.',
	'Trigger has been altered.' => 'Le trigger a été modifié.',
	'Trigger has been created.' => 'Le trigger a été créé.',
	'Alter trigger' => 'Modifier un trigger',
	'Create trigger' => 'Ajouter un trigger',
	'Time' => 'Temps',
	'Event' => 'Évènement',
	'%d row(s)' => array('%d ligne', '%d lignes'),
	'Remove' => 'Effacer',
	'Are you sure?' => 'Êtes-vous certain ?',
	'Privileges' => 'Privilèges',
	'Create user' => 'Créer un utilisateur',
	'User has been dropped.' => 'L\'utilisateur a été effacé.',
	'User has been altered.' => 'L\'utilisateur a été modifié.',
	'User has been created.' => 'L\'utilisateur a été créé.',
	'Hashed' => 'Haché',
	'Column' => 'Colonne',
	'Routine' => 'Routine',
	'Grant' => 'Grant',
	'Revoke' => 'Revoke',
	'%s version: %s through PHP extension %s' => 'Version de %s : %s via l\'extension PHP %s',
	'Logged as: %s' => 'Authentifié en tant que : %s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Données POST trop grandes. Réduisez la taille des données ou augmentez la valeur de %s dans la configuration de PHP.',
	'Move up' => 'Déplacer vers le haut',
	'Move down' => 'Déplacer vers le bas',
	'Export' => 'Exporter',
	'Tables' => 'Tables',
	'Data' => 'Données',
	'Output' => 'Sortie',
	'open' => 'ouvrir',
	'save' => 'sauvegarder',
	'Format' => 'Format',
	'Functions' => 'Fonctions',
	'Aggregation' => 'Agrégation',
	'Event has been dropped.' => 'L\'évènement a été supprimé.',
	'Event has been altered.' => 'L\'évènement a été modifié.',
	'Event has been created.' => 'L\'évènement a été créé.',
	'Alter event' => 'Modifier un évènement',
	'Create event' => 'Créer un évènement',
	'Start' => 'Démarrer',
	'End' => 'Terminer',
	'Every' => 'Chaque',
	'Status' => 'Statut',
	'On completion preserve' => 'Conserver quand complété',
	'Events' => 'Évènements',
	'Schedule' => 'Horaire',
	'At given time' => 'À un moment précis',
	'Save and continue edit' => 'Sauvegarder et continuer l\'édition',
	'original' => 'original',
	'Tables have been truncated.' => 'Les tables ont été tronquées.',
	'Tables have been moved.' => 'Les tables ont été déplacées.',
	'Tables have been dropped.' => 'Les tables ont été effacées.',
	'Tables and views' => 'Tables et vues',
	'Engine' => 'Moteur',
	'Collation' => 'Interclassement',
	'Data Length' => 'Longueur des données',
	'Index Length' => 'Longueur de l\'index',
	'Data Free' => 'Espace inutilisé',
	'Rows' => 'Lignes',
	',' => ',',
	'Analyze' => 'Analyser',
	'Optimize' => 'Optimiser',
	'Check' => 'Vérifier',
	'Repair' => 'Réparer',
	'Truncate' => 'Tronquer',
	'Move to other database' => 'Déplacer vers une autre base de données',
	'Move' => 'Déplacer',
	'%d item(s) have been affected.' => array('%d élément a été modifié.', '%d éléments ont été modifiés.'),
	'whole result' => 'résultat entier',
	'Clone' => 'Cloner',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Le nombre maximum de champs est dépassé. Veuillez augmenter %s et %s.',
	'Partition by' => 'Partitionner par',
	'Partitions' => 'Partitions',
	'Partition name' => 'Nom de la partition',
	'Values' => 'Valeurs',
	'%d row(s) have been imported.' => array('%d ligne a été importée.','%d lignes ont été importées.'),
	'anywhere' => 'n\'importe où',
	'Import' => 'Importer',
	'Stop on error' => 'Arrêter en cas d\'erreur',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'jj/mm/[aaaa]',
	'History' => 'Historique',
	'Variables' => 'Variables',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Les colonnes de source et de destination doivent être du même type, il doit y avoir un index sur les colonnes de destination et les données référencées doivent exister.',
	'Relations' => 'Relations',
	'Run file' => 'Exécuter le fichier',
	'Clear' => 'Effacer',
	'Maximum allowed file size is %sB.' => 'La taille maximale des fichiers est de %sB.',
	'Numbers' => 'Nombres',
	'Date and time' => 'Date et heure',
	'Strings' => 'Chaînes',
	'Binary' => 'Binaires',
	'Lists' => 'Listes',
	'Editor' => 'Éditeur',
	'E-mail' => 'Courriel',
	'From' => 'De',
	'Subject' => 'Sujet',
	'Send' => 'Envoyer',
	'%d e-mail(s) have been sent.' => array('%d message a été envoyé.', '%d messages ont été envoyés.'),
	'Webserver file %s' => 'Fichier %s du serveur Web',
	'File does not exist.' => 'Le fichier est introuvable.',
	'%d in total' => '%d au total',
	'Permanent login' => 'Authentification permanente',
	'Databases have been dropped.' => 'Les bases de données ont été supprimées.',
	'Database has been dropped.' => 'La base de données a été supprimée.',
	'Search data in tables' => 'Rechercher dans les tables',
	'schema' => 'schéma',
	'Schema' => 'Schéma',
	'Alter schema' => 'Modifier le schéma',
	'Create schema' => 'Créer un schéma',
	'Schema has been dropped.' => 'Le schéma a été supprimé.',
	'Schema has been created.' => 'Le schéma a été créé.',
	'Schema has been altered.' => 'Le schéma a été modifié.',
	'Sequences' => 'Séquences',
	'Create sequence' => 'Créer une séquence',
	'Alter sequence' => 'Modifier la séquence',
	'Sequence has been dropped.' => 'La séquence a été supprimée.',
	'Sequence has been created.' => 'La séquence a été créée.',
	'Sequence has been altered.' => 'La séquence a été modifiée.',
	'User types' => 'Types utilisateur',
	'Create type' => 'Créer un type',
	'Alter type' => 'Modifier le type',
	'Type has been dropped.' => 'Le type a été supprimé.',
	'Type has been created.' => 'Le type a été créé.',
	'Ctrl+click on a value to modify it.' => 'Ctrl+cliquez sur une valeur pour la modifier.',
	'Use edit link to modify this value.' => 'Utilisez le lien "modifier" pour modifier cette valeur.',
	'last' => 'dernière',
	'From server' => 'Depuis le serveur',
	'System' => 'Système',
	'Select data' => 'Afficher les données',
	'Show structure' => 'Afficher la structure',
	'empty' => 'vide',
	'Network' => 'Réseau',
	'Geometry' => 'Géométrie',
	'File exists.' => 'Le fichier existe.',
	'Attachments' => 'Pièces jointes',
	'Item%s has been inserted.' => 'L\'élément%s a été inséré.',
	'now' => 'maintenant',
	'%d query(s) executed OK.' => array('%d requête exécutée avec succès.', '%d requêtes exécutées avec succès.'),
	'Show only errors' => 'Montrer seulement les erreurs',
	'Last page' => 'Dernière page',
	'Refresh' => 'Rafraîchir',
	'Invalid schema.' => 'Schéma invalide.',
	'Please use one of the extensions %s.' => 'Veuillez utiliser l\'une des extensions %s.',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Les tables ont été copiées.',
	'Copy' => 'Copier',
	'Permanent link' => 'Lien permanent',
	'Edit all' => 'Tout modifier',
	'HH:MM:SS' => 'HH:MM:SS',
);

==> adminer-3.7.0.tbz: www/adminer/adminer/lang/fr.inc.php <==
<?php
$translations = array(
	'Login' => 'Authentification',
	'Logout successful.' => 'Au revoir !',
	'Invalid credentials.' => 'Authentification échouée.',
	'Server' => 'Serveur',
	'Username' => 'Utilisateur',
	'Password' => 'Mot de passe',
	'Select database' => 'Sélectionner la base de données',
	'Invalid database.' => 'Base de données invalide.',
	'Create new database' => 'Créer une base de données',
	'Table has been dropped.' => 'La table a été effacée.',
	'Table has been altered.' => 'La table a été modifiée.',
	'Table has been created.' => 'La table a été créée.',
	'Alter table' => 'Modifier la table',
	'Create table' => 'Créer une table',
	'Table name' => 'Nom de la table',
	'engine' => 'moteur',
	'collation' => 'interclassement',
	'Column name' => 'Nom de la colonne',
	'Type' => 'Type',
	'Length' => 'Longueur',
	'Auto Increment' => 'Auto increment',
	'Options' => 'Options',
	'Save' => 'Enregistrer',
	'Drop' => 'Supprimer',
	'Database has been created.' => 'La base de données a été créée.',
	'Database has been renamed.' => 'La base de données a été renommée.',
	'Database has been altered.' => 'La base de données a été modifiée.',
	'Alter database' => 'Modifier la base de données',
	'Create database' => 'Créer une base de données',
	'SQL command' => 'Requête SQL',
	'Dump' => 'Exporter',
	'Logout' => 'Déconnexion',
	'database' => 'base de données',
	'Use' => 'Utiliser',
	'No tables.' => 'Aucune table.',
	'select' => 'select',
	'Create new table' => 'Créer une nouvelle table',
	'Item has been deleted.' => 'L\'élément a été supprimé.',
	'Item has been updated.' => 'L\'élément a été modifié.',
	'Edit' => 'Modifier',
	'Insert' => 'Insérer',
	'Save and insert next' => 'Enr. et insérer prochain',
	'Delete' => 'Effacer',
	'Database' => 'Base de données',
	'Routines' => 'Routines',
	'Indexes have been altered.' => 'Index modifiés.',
	'Indexes' => 'Index',
	'Alter indexes' => 'Modifier les index',
	'Add next' => 'Ajouter le prochain',
	'Language' => 'Langue',
	'Select' => 'Select',
	'New item' => 'Nouvel élément',
	'Search' => 'Rechercher',
	'Sort' => 'Trier',
	'descending' => 'décroissant',
	'Limit' => 'Limite',
	'No rows.' => 'Aucun résultat.',
	'Action' => 'Action',
	'edit' => 'modifier',
	'Page' => 'Page',
	'Query executed OK, %d row(s) affected.' => array('Requête exécutée avec succès, %d ligne modifiée.', 'Requête exécutée avec succès, %d lignes modifiées.'),
	'Error in query' => 'Erreur dans la requête',
	'Execute' => 'Exécuter',
	'Table' => 'Table',
	'Foreign keys' => 'Clés étrangères',
	'Triggers' => 'Triggers',
	'View' => 'Vue',
	'Unable to select the table' => 'Impossible de sélectionner la table',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF invalide. Veuillez réenvoyer le formulaire.',
	'Comment' => 'Commentaire',
	'Default values' => 'Valeurs par défaut',
	'%d byte(s)' => array('%d octet', '%d octets'),
	'No commands to execute.' => 'Aucune commande à exécuter.',
	'Unable to upload a file.' => 'Impossible d\'importer le fichier.',
	'File upload' => 'Importer un fichier',
	'File uploads are disabled.' => 'L\'importation de fichier est désactivée.',
	'Routine has been called, %d row(s) affected.' => array('La routine a été exécutée, %d ligne modifiée.', 'La routine a été exécutée, %d lignes modifiées.'),
	'Call' => 'Appeler',
	'No extension' => 'Extension introuvable',
	'None of the supported PHP extensions (%s) are available.' => 'Aucune des extensions PHP supportées (%s) n\'est disponible.',
	'Session support must be enabled.' => 'Veuillez activer les sessions.',
	'Session expired, please login again.' => 'Session expirée, veuillez vous authentifier à nouveau.',
	'Text length' => 'Longueur du texte',
	'Foreign key has been dropped.' => 'La clé étrangère a été effacée.',
	'Foreign key has been altered.' => 'La clé étrangère a été modifiée.',
	'Foreign key has been created.' => 'La clé étrangère a été créée.',
	'Foreign key' => 'Clé étrangère',
	'Target table' => 'Table visée',
	'Change' => 'Modifier',
	'Source' => 'Source',
	'Target' => 'Cible',
	'Add column' => 'Ajouter une colonne',
	'Alter' => 'Modifier',
	'Add foreign key' => 'Ajouter une clé étrangère',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Type d\'index',
	'Column (length)' => 'Colonne (longueur)',
	'View has been dropped.' => 'La vue a été effacée.',
	'View has been altered.' => 'La vue a été modifiée.',
	'View has been created.' => 'La vue a été créée.',
	'Alter view' => 'Modifier une vue',
	'Create view' => 'Créer une vue',
	'Name' => 'Nom',
	'Process list' => 'Liste des processus',
	'%d process(es) have been killed.' => array('%d processus a été arrêté.', '%d processus ont été arrêtés.'),
	'Kill' => 'Arrêter',
	'Parameter name' => 'Nom du paramètre',
	'Database schema' => 'Schéma de la base de données',
	'Create procedure' => 'Créer une procédure',
	'Create function' => 'Créer une fonction',
	'Routine has been dropped.' => 'La routine a été supprimée.',
	'Routine has been altered.' => 'La routine a été modifiée.',
	'Routine has been created.' => 'La routine a été créée.',
	'Alter function' => 'Modifier la fonction',
	'Alter procedure' => 'Modifier la procédure',
	'Return type' => 'Type de retour',
	'Add trigger' => 'Ajouter un trigger',
	'Trigger has been dropped.' => 'Le trigger a été supprimé.',
	'Trigger has been altered.' => 'Le trigger a été modifié.',
	'Trigger has been created.' => 'Le trigger a été créé.',
	'Alter trigger' => 'Modifier un trigger',
	'Create trigger' => 'Ajouter un trigger',
	'Time' => 'Temps',
	'Event' => 'Évènement',
	'%d row(s)' => array('%d ligne', '%d lignes'),
	'Remove' => 'Effacer',
	'Are you sure?' => 'Êtes-vous certain ?',
	'Privileges' => 'Privilèges',
	'Create user' => 'Créer un utilisateur',
	'User has been dropped.' => 'L\'utilisateur a été effacé.',
	'User has been altered.' => 'L\'utilisateur a été modifié.',
	'User has been created.' => 'L\'utilisateur a été créé.',
	'Hashed' => 'Haché',
	'Column' => 'Colonne',
	'Routine' => 'Routine',
	'Grant' => 'Grant',
	'Revoke' => 'Revoke',
	'%s version: %s through PHP extension %s' => 'Version de %s : %s via l\'extension PHP %s',
	'Logged as: %s' => 'Authentifié en tant que : %s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Données POST trop grandes. Réduisez la taille des données ou augmentez la valeur de %s dans la configuration de PHP.',
	'Move up' => 'Déplacer vers le haut',
	'Move down' => 'Déplacer vers le bas',
	'Export' => 'Exporter',
	'Tables' => 'Tables',
	'Data' => 'Données',
	'Output' => 'Sortie',
	'open' => 'ouvrir',
	'save' => 'enregistrer',
	'Format' => 'Format',
	'Functions' => 'Fonctions',
	'Aggregation' => 'Agrégation',
	'Event has been dropped.' => 'L\'évènement a été supprimé.',
	'Event has been altered.' => 'L\'évènement a été modifié.',
	'Event has been created.' => 'L\'évènement a été créé.',
	'Alter event' => 'Modifier un évènement',
	'Create event' => 'Créer un évènement',
	'Start' => 'Démarrer',
	'End' => 'Terminer',
	'Every' => 'Chaque',
	'Status' => 'Statut',
	'On completion preserve' => 'Conserver quand complété',
	'Events' => 'Évènements',
	'Schedule' => 'Horaire',
	'At given time' => 'À un moment précis',
	'Save and continue edit' => 'Enr. et continuer édition',
	'original' => 'original',
	'Tables have been truncated.' => 'Les tables ont été tronquées.',
	'Tables have been moved.' => 'Les tables ont été déplacées.',
	'Tables have been dropped.' => 'Les tables ont été effacées.',
	'Tables and views' => 'Tables et vues',
	'Engine' => 'Moteur',
	'Collation' => 'Interclassement',
	'Data Length' => 'Longueur des données',
	'Index Length' => 'Longueur de l\'index',
	'Data Free' => 'Espace inutilisé',
	'Rows' => 'Lignes',
	',' => ',',
	'Analyze' => 'Analyser',
	'Optimize' => 'Optimiser',
	'Check' => 'Vérifier',
	'Repair' => 'Réparer',
	'Truncate' => 'Tronquer',
	'Move to other database' => 'Déplacer vers une autre base de données',
	'Move' => 'Déplacer',
	'%d item(s) have been affected.' => array('%d élément a été modifié.', '%d éléments ont été modifiés.'),
	'whole result' => 'résultat entier',
	'Clone' => 'Cloner',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Le nombre maximum de champs est dépassé. Veuillez augmenter %s.',
	'Partition by' => 'Partitionner par',
	'Partitions' => 'Partitions',
	'Partition name' => 'Nom de la partition',
	'Values' => 'Valeurs',
	'%d row(s) have been imported.' => array('%d ligne a été importée.','%d lignes ont été importées.'),
	'anywhere' => 'n\'importe où',
	'Import' => 'Importer',
	'Stop on error' => 'Arrêter en cas d\'erreur',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'jj/mm/[aaaa]',
	'History' => 'Historique',
	'Variables' => 'Variables',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Les colonnes de source et de destination doivent être du même type, il doit y avoir un index sur les colonnes de destination et les données référencées doivent exister.',
	'Relations' => 'Relations',
	'Run file' => 'Exécuter le fichier',
	'Clear' => 'Effacer',
	'Maximum allowed file size is %sB.' => 'La taille maximale des fichiers est de %sB.',
	'Numbers' => 'Nombres',
	'Date and time' => 'Date et heure',
	'Strings' => 'Chaînes',
	'Binary' => 'Binaires',
	'Lists' => 'Listes',
	'Editor' => 'Éditeur',
	'E-mail' => 'Courriel',
	'From' => 'De',
	'Subject' => 'Sujet',
	'Send' => 'Envoyer',
	'%d e-mail(s) have been sent.' => array('%d message a été envoyé.', '%d messages ont été envoyés.'),
	'Webserver file %s' => 'Fichier %s du serveur Web',
	'File does not exist.' => 'Le fichier est introuvable.',
	'%d in total' => '%d au total',
	'Permanent login' => 'Authentification permanente',
	'Databases have been dropped.' => 'Les bases de données ont été supprimées.',
	'Database has been dropped.' => 'La base de données a été supprimée.',
	'Search data in tables' => 'Rechercher dans les tables',
	'schema' => 'schéma',
	'Schema' => 'Schéma',
	'Alter schema' => 'Modifier le schéma',
	'Create schema' => 'Créer un schéma',
	'Schema has been dropped.' => 'Le schéma a été supprimé.',
	'Schema has been created.' => 'Le schéma a été créé.',
	'Schema has been altered.' => 'Le schéma a été modifié.',
	'Sequences' => 'Séquences',
	'Create sequence' => 'Créer une séquence',
	'Alter sequence' => 'Modifier la séquence',
	'Sequence has been dropped.' => 'La séquence a été supprimée.',
	'Sequence has been created.' => 'La séquence a été créée.',
	'Sequence has been altered.' => 'La séquence a été modifiée.',
	'User types' => 'Types utilisateur',
	'Create type' => 'Créer un type',
	'Alter type' => 'Modifier le type',
	'Type has been dropped.' => 'Le type a été supprimé.',
	'Type has been created.' => 'Le type a été créé.',
	'Ctrl+click on a value to modify it.' => 'Ctrl+cliquez sur une valeur pour la modifier.',
	'Use edit link to modify this value.' => 'Utilisez le lien "modifier" pour modifier cette valeur.',
	'last' => 'dernière',
	'From server' => 'Depuis le serveur',
	'System' => 'Système',
	'Select data' => 'Afficher les données',
	'Show structure' => 'Afficher la structure',
	'empty' => 'vide',
	'Network' => 'Réseau',
	'Geometry' => 'Géométrie',
	'File exists.' => 'Le fichier existe.',
	'Attachments' => 'Pièces jointes',
	'Item%s has been inserted.' => 'L\'élément%s a été inséré.',
	'now' => 'maintenant',
	'%d query(s) executed OK.' => array('%d requête exécutée avec succès.', '%d requêtes exécutées avec succès.'),
	'Show only errors' => 'Montrer seulement les erreurs',
	'Refresh' => 'Rafraîchir',
	'Invalid schema.' => 'Schéma invalide.',
	'Please use one of the extensions %s.' => 'Veuillez utiliser l\'une des extensions %s.',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Les tables ont été copiées.',
	'Copy' => 'Copier',
	'Permanent link' => 'Lien permanent',
	'Edit all' => 'Tout modifier',
	'HH:MM:SS' => 'HH:MM:SS',
);
